==> haskell-logging-facade-0.3.1-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-2uGr2njzsdRpP9lknrtEO
key:                  logging-facade-0.3.1-2uGr2njzsdRpP9lknrtEO
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  324aafd6fb71e556f5c26e14007c0e06
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.0.2/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-2uGr2njzsdRpP9lknrtEO
depends:
    base-4.15.1.0 call-stack-0.4.0-AWZIvDgVjrSE2X5Lpd2ZLj
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.1-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-BRH4adFqmLe6VbEz8yXavu
key:                  logging-facade-0.3.1-BRH4adFqmLe6VbEz8yXavu
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  0a7a457ff9bf312e60cf3d650e37c93e
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.0.2/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-BRH4adFqmLe6VbEz8yXavu
depends:
    base-4.15.1.0 call-stack-0.4.0-AWZIvDgVjrSE2X5Lpd2ZLj
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
